==> cvstrac-1.1.0.tar.gz: cvstrac-1.1.0/index.c <==
/*
** Copyright (c) 2002 D. Richard Hipp
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** General Public License for more details.
** 
** You should have received a copy of the GNU General Public
** License along with this library; if not, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA  02111-1307, USA.
**
** Author contact information:
**   drh@hwaci.com
**   http://www.hwaci.com/drh/
**
*******************************************************************************
**
** Code to generate the index page
*/
#include "config.h"
#include "index.h"

/*
** WEBPAGE: /
** WEBPAGE: /index
*/
void index_page(void){
  static const char *azLink[] = { 0, };
  login_check_credentials();
  common_header("Main Index", azLink);
  @ <table cellpadding="10">
  @
  if( g.okNewTkt ){
    @ <tr>
    @ <td valign="top">
    @ <a href="tktnew"><b>New</b></a>
    @ </td>
    @ <td valign="top">
    @ Create a new defect report or enhancement request.
    @ </td>
    @ </tr>
    @
  }
  if( g.okCheckout ){
    @ <tr>
    @ <td valign="top">
    @ <a href="dir"><b>Browse</b></a>
    @ </td>
    @ <td valign="top">
    @ Browse the CVS repository tree
    @ </td>
    @ </tr>
    @
  }   
  if( g.okRead ){
    @ <tr>
    @ <td valign="top">
    @ <a href="reportlist"><b>Reports</b></a>
    @ </td>
    @ <td valign="top">
    @ View summary reports of tickets.
    @ </td>
    @ </tr>
    @
  }
  if( g.okRead || g.okCheckout ){
    @ <tr>
    @ <td valign="top">
    @ <a href="timeline"><b>Timeline</b></a>
    @ </td>
    @ <td valign="top">
    @ View a chronology of code checkins and bug fixes.
    @ </td>
    @ </tr>
    @ 
  }
  @ <tr>
  @ <td valign="top">
  @ <a href="wiki"><b>Wiki</b></a>
  @ </td>
  @ <td valign="top">
  @ View the Wiki documentation pages
  @ </td>
  @ </tr>
  @
  @ <tr>
  @ <td valign="top">
  @ <a href="search"><b>Search</b></a>
  @ </td>
  @ <td valign="top">
  if( g.okRead && g.okCheckout ){
    @ Search for keywords in Tickets, Check-ins, and/or Wiki pages.
  }else if( g.okRead ){
    @ Search for keywords in Tickets and/or Wiki pages
  }else if( g.okCheckout ){
    @ Search for keywords in Check-ins and/or Wiki pages
  }else{
    @ Search for keywords in Wiki pages
  }
  @ </td>
  @ </tr>
  @
  if( g.okCheckin ){
    @ <tr>
    @ <td valign="top">
    @ <a href="msnew"><b>Milestones</b></a>
    @ </td>
    @ <td valign="top">
    @ Create new project milestones (such as releases or builds).
    @ </td>
    @ </tr>
    @ 
  }
  if( g.okWrite && !g.isAnon ){
    @ <tr>
    @ <td valign="top">
    @ <a href="userlist"><b>User</b></a>
    @ </td>
    @ <td valign="top">
    @ Create, edit, and delete users.
    @ </td>
    @ </tr>
    @ 
  }
  if( g.okAdmin ){
    @ <tr>
    @ <td valign="top">
    @ <a href="setup"><b>Setup</b></a>
    @ </td>
    @ <td valign="top">
    @ Initial server setup such as specifying the CVS root directory.
    @ </td>
    @ </tr>
    @ 
  }
  if( g.isAnon ){
    @ <tr>
    @ <td valign="top">
    @ <a href="login"><b>Login</b></a>
    @ </td>
    @ <td valign="top">
    @ Log in.  You will need to enter your
    @ user ID and password.
    @ </td>
    @ </tr>
    @ 
  }else{
    @ <tr>
    @ <td valign="top">
    @ <a href="logout"><b>Logout</b></a>
    @ </td>
    @ <td valign="top">
    @ Log off.  You will need to re-enter your
    @ user ID and password to get back in again.
    @ </td>
    @ </tr>
    @ 
  }
  @ </table>
  @ 
  common_footer();
}

==> cvstrac-1.1.1.tar.gz: cvstrac-1.1.1/index.c <==
/*
** Copyright (c) 2002 D. Richard Hipp
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** General Public License for more details.
** 
** You should have received a copy of the GNU General Public
** License along with this library; if not, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA  02111-1307, USA.
**
** Author contact information:
**   drh@hwaci.com
**   http://www.hwaci.com/drh/
**
*******************************************************************************
**
** Code to generate the index page
*/
#include "config.h"
#include "index.h"

/*
** WEBPAGE: /
** WEBPAGE: /index
*/
void index_page(void){
  int cnt = 0;
  static const char *azLink[] = { 0, };
  login_check_credentials();
  common_header("Main Index", azLink);
  @ <table cellpadding="10">
  @
  if( g.okNewTkt ){
    @ <tr>
    @ <td valign="top">
    @ <a href="tktnew"><b>New</b></a>
    @ </td>
    @ <td valign="top">
    @ Create a new Ticket with a defect report or enhancement request.
    @ </td>
    @ </tr>
    @
    cnt++;
  }
  if( g.okCheckout ){
    @ <tr>
    @ <td valign="top">
    @ <a href="dir"><b>Browse</b></a>
    @ </td>
    @ <td valign="top">
    @ Browse the CVS repository tree.
    @ </td>
    @ </tr>
    @
    cnt++;
  }   
  if( g.okRead ){
    @ <tr>
    @ <td valign="top">
    @ <a href="reportlist"><b>Reports</b></a>
    @ </td>
    @ <td valign="top">
    @ View summary reports of Tickets.
    @ </td>
    @ </tr>
    @
    cnt++;
  }
  if( g.okRead || g.okCheckout ){
    @ <tr>
    @ <td valign="top">
    @ <a href="timeline"><b>Timeline</b></a>
    @ </td>
    @ <td valign="top">
    @ View a chronology of Check-Ins and Ticket changes.
    @ </td>
    @ </tr>
    @ 
    cnt++;
  }
  if( g.okRdWiki ){
    @ <tr>
    @ <td valign="top">
    @ <a href="wiki"><b>Wiki</b></a>
    @ </td>
    @ <td valign="top">
    @ View the Wiki documentation pages.
    @ </td>
    @ </tr>
    @
    cnt++;
  }
  if( g.okRead || g.okCheckout || g.okRdWiki ){
    const char *az[3];
    int n=0;
    if( g.okRead ) az[n++] = "Tickets";
    if( g.okCheckout ) az[n++] = "Check-ins";
    if( g.okRdWiki ) az[n++] = "Wiki pages";
    @ <tr>
    @ <td valign="top">
    @ <a href="search"><b>Search</b></a>
    @ </td>
    @ <td valign="top">
    if( n==3 ){
      @ Search for keywords in Tickets, Check-ins, and/or Wiki pages.
    }else if( n==2 ){
      @ Search for keywords in %s(az[0]) and/or %s(az[1])
    }else{
      @ Search for keywords in %s(az[0])
    }
    @ </td>
    @ </tr>
    @
    cnt++;
  }
  if( g.okCheckin ){
    @ <tr>
    @ <td valign="top">
    @ <a href="msnew"><b>Milestones</b></a>
    @ </td>
    @ <td valign="top">
    @ Create new project milestones.
    @ </td>
    @ </tr>
    @ 
    cnt++;
  }
  if( g.okWrite && !g.isAnon ){
    @ <tr>
    @ <td valign="top">
    @ <a href="userlist"><b>User</b></a>
    @ </td>
    @ <td valign="top">
    @ Create, edit, and delete users.
    @ </td>
    @ </tr>
    @ 
    cnt++;
  }
  if( g.okAdmin ){
    @ <tr>
    @ <td valign="top">
    @ <a href="setup"><b>Setup</b></a>
    @ </td>
    @ <td valign="top">
    @ Setup global system parameters.
    @ </td>
    @ </tr>
    @ 
    cnt++;
  }
  if( g.isAnon ){
    if( cnt==0 ){
      cgi_redirect("login");
      return;
    }
    @ <tr>
    @ <td valign="top">
    @ <a href="login"><b>Login</b></a>
    @ </td>
    @ <td valign="top">
    @ Log in.
    @ </td>
    @ </tr>
    @ 
  }else{
    @ <tr>
    @ <td valign="top">
    @ <a href="logout"><b>Logout</b></a>
    @ </td>
    @ <td valign="top">
    @ Log off or change password.
    @ </td>
    @ </tr>
    @ 
  }
  @ </table>
  @ 
  common_footer();
}
